@@ -1,5 +1,6 @@
 import ConfigParser
 import argparse
+import collections
 import datetime
 import httplib
 import json
@@ -301,9 +302,10 @@ class SoftwareReleaseTester(RPCRetry):
             stepfunc(self)
         return self.deadline
 
+
 class TestMap(object):
    def __init__(self, test_dict):
-       self.test_map_dict = {}
+       self.test_map_dict = collections.OrderedDict()
        for key in test_dict:
            target_computer = test_dict[key]["target_computer"]
            if target_computer not in self.test_map_dict:
@@ -373,28 +375,30 @@ def main():
             key_file_dict[cert] = (temp_key, temp_cert)
         return temp_key.name, temp_cert.name
     args = parser.parse_args()
+
+    log = args.log
+    formatter = logging.Formatter('%(asctime)s %(message)s')
+    logger = logging.getLogger()
+    if args.verbose:
+        log_level = logging.DEBUG
+    else:
+        log_level = logging.INFO
+    logger.setLevel(log_level)
+    handler = logging.StreamHandler(sys.stdout)
+    handler.setFormatter(formatter)
+    logger.addHandler(handler)
+    if log:
+        handler = logging.FileHandler(log)
+        handler.setFormatter(formatter)
+        logger.addHandler(handler)
+        log_file = open(log)
+        log_file.seek(0, 2)
+
     pidfile = args.pidfile
     if pidfile:
         setRunning(pidfile)
     try:
-        log = args.log
-        formatter = logging.Formatter('%(asctime)s %(message)s')
-        logger = logging.getLogger()
-        if args.verbose:
-            log_level = logging.DEBUG
-        else:
-            log_level = logging.INFO
-        logger.setLevel(log_level)
-        handler = logging.StreamHandler(sys.stdout)
-        handler.setFormatter(formatter)
-        logger.addHandler(handler)
-        if log:
-            handler = logging.FileHandler(log)
-            handler.setFormatter(formatter)
-            logger.addHandler(handler)
-            log_file = open(log)
-            log_file.seek(0, 2)
-        section_dict = {}
+        section_dict = collections.OrderedDict()
         configuration = ConfigParser.SafeConfigParser()
         configuration.readfp(args.configuration_file)
         for section in configuration.sections():
